@@ -1,11 +1,12 @@
 package Module::Install::Admin::ScanDeps;
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.84';
-
 use strict;
+use Module::Install::Base ();
+use vars qw{$VERSION @ISA};
+BEGIN {
+	$VERSION = '0.85';
+	@ISA = qw(Module::Install::Base);
+}
 
 sub scan_dependencies {
     my ($self, $pkg, $perl_version) = @_;
